@@ -58,62 +58,62 @@ def create_intc_zeros_as_CFFI_int( n):
 
 # use numpy to create an float array with n zeros and cast to CFFI 
 def create_float_zeros_as_CFFI_double( n):
-    x = np.zeros( n, float)
+    x = np.zeros( n, np.float64)
     px = ffi.cast( "double *", x.ctypes.data)
     return x, px
 
 def convert_py_float_to_cffi( x):
-    if isinstance( x, np.ndarray) or x != None:
-        if not isinstance( x, np.ndarray) or ( x.flags.c_contiguous == False) or ( x.dtype != np.float64):
+    if isinstance( x, np.ndarray) == True:
+        px = np.ascontiguousarray( x, dtype = 'float64')
+    else:
+        if x != None:
             px = np.ascontiguousarray( x, dtype = 'float64')
         else:
-            px = x
-    else: 
-        # handle None
-        px = np.array( 0.0)
-    
+            # handle None
+           px = np.array( 0.0)
+           # pxcffi = ffi.cast( "double *", 0.0)            
     pxcffi = ffi.cast( "double *", px.ctypes.data)
     return px, pxcffi
 
-# def convert_py_float_to_cffi( x):
-#     if isinstance( x, np.ndarray) == True:
-#         px = np.ascontiguousarray( x, dtype = 'float64')
-#     else:
-#         if x != None:
-#             px = np.ascontiguousarray( x, dtype = 'float64')
-#         else:
-#             # handle None
-#            px = np.array( 0.0)
-#            # pxcffi = ffi.cast( "double *", 0.0)            
-#     pxcffi = ffi.cast( "double *", px.ctypes.data)
-#     return px, pxcffi
 
 def convert_py_int_to_cffi( x):
-    if isinstance( x, np.ndarray) or x != None:
-        if not isinstance( x, np.ndarray) or ( x.flags.c_contiguous == False) or ( x.dtype != np.int32):
-            px = np.ascontiguousarray( x, dtype = 'int32')
-        else:
-            px = x
+    if x != None:
+        x = np.intc( x)
+        px = np.array( x)
+        pxcffi = ffi.cast( "int *", px.ctypes.data)
     else: 
         # handle None
         px = np.array( 0)
-    pxcffi = ffi.cast( "double *", px.ctypes.data)
+        pxcffi = ffi.cast( "int *", 0)
     return px, pxcffi
 
-   
+# def convert_py_float_to_cffi( x):
+#     if isinstance( x, np.ndarray) or x != None:
+#         if not isinstance( x, np.ndarray) or ( x.flags.c_contiguous == False) or ( x.dtype != np.float64):
+#             px = np.ascontiguousarray( x, dtype = 'float64')
+#         else:
+#             px = x
+#     else: 
+#         # handle None
+#         px = np.array( 0.0)
+    
+#     pxcffi = ffi.cast( "double *", px.ctypes.data)
+#     return px, pxcffi
+
 # def convert_py_int_to_cffi( x):
-#     if x != None:
-#         x = np.intc( x)
-#         px = np.array( x)
-#         pxcffi = ffi.cast( "int *", px.ctypes.data)
+#     if isinstance( x, np.ndarray) or x != None:
+#         if not isinstance( x, np.ndarray) or ( x.flags.c_contiguous == False) or ( x.dtype != np.int32):
+#             px = np.ascontiguousarray( x, dtype = 'int32')
+#             pxcffi = ffi.cast( "int *", px.ctypes.data)
+#         else:
+#             px = x
 #     else: 
 #         # handle None
 #         px = np.array( 0)
 #         pxcffi = ffi.cast( "int *", 0)
+        
 #     return px, pxcffi
 
-
-
 ###
 # Python wrapper classes 
 ###
