@@ -61,8 +61,8 @@ using namespace std;
 #else
 extern "C" {
 // change this line if glpk is installed on your system
-#include "../glpk/include/glpk.h"
-//#include <glpk.h>
+//#include "../glpk/include/glpk.h"
+#include <glpk.h>
 }
 #endif
 
